@@ -1,6 +1,5 @@
 ﻿import os
 import click
-from gdcmd.helm.deployment_test import deployment_test
 from gdcmd.helm.list_charts import list_charts
 from gdcmd.helm.template import template
 from gdcmd.helm.validate import validate
@@ -107,13 +106,6 @@ def helm_validate(values: tuple[str]):
     validate(values)
 
 
-@helm.command("deployment-test", short_help="Tests the griddot/suite deployment installation")
-@click.option('--path', '-p', multiple=True, help='Path to the values.yaml file, generated by the griddot/suite deployment itself.')
-@click.option('--verbose', '-v', help='Verbose output', is_flag=True, default=False)
-def helm_deployment_test(path: str, verbose: bool):
-    deployment_test(path, verbose)
-
-
 cli.add_command(secrets)
 cli.add_command(keycloak)
 cli.add_command(helm)
