@@ -160,14 +160,15 @@ class Common(BaseModel):
 
     requireHttps: bool = Field(default=False, description="Set to true if you want to enforce HTTPS with self-signed certificates")
     identity: Identity = Field(default=Identity(), description="")
+    allowUnsafeCertificates: bool = Field(default=False, description="If true, TLS certificate validation is skipped, useful for self-signed certificates")
+    certificateBase64: str | None = Field(default=None, description="If set, this should contain a base64 encoded custom TLS certificate in pfx format, used if common.requireHttps is true")
     certificatePassword: str = Field(default="z98M9gFsF7aJBn3s", description="Certificate password for self-signed certificates, used if common.requireHttps is true")
     reseller: str = Field(default="reseller-name", description="Reseller name")
     deploymentId: str = Field(default="deployment-id", description="Each deployment should have a unique id!")
     host: str = Field(default="localhost", description="Host name or ip where all apps are reachable from")
     timeZoneIdOverride: str | None = Field(default=None, description="If set, overrides the time zone id detected from the environment")
     develSimulationTimeProviderEnabled: bool = Field(default=False, description="For development purposes only, enables simulated time")
-    customCertBase64: str | None = Field(default=None, description="If set, this should contain a base64 encoded custom TLS certificate in pfx format, used if common.requireHttps is true")
-    customCertPass: str | None = Field(default=None, description="If customCertBase64 is set and this contains the password for the custom certificate, used if common.requireHttps is true")
+    validUris: List[str] = Field(default=[], description="List of valid redirect urls for identity provider, e.g., [\"https://mydomain.com:7080/*\"]")
 
 
 class ValuesYaml(BaseModel):
@@ -200,11 +201,9 @@ class ValuesYaml(BaseModel):
         if " " in self.common.deploymentId:
             raise ValueError("common.deploymentId cannot contain spaces")
 
-        if self.common.customCertBase64:
+        if self.common.certificateBase64:
             if not self.common.requireHttps:
-                raise ValueError("common.requireHttps must be true if common.customCertBase64 is set")
-            if self.common.customCertPass is None:
-                raise ValueError("common.customCertPass must be set at least to empty string if common.customCertBase64 is set")
+                raise ValueError("common.requireHttps must be true if common.certificateBase64 is set")
 
         # Prometheus
         if self.prometheus.databaseExporter and not self.deploy.db:
