@@ -17,7 +17,7 @@ def test_serialization_to_from_dict():
 
 def test_validation_work_on_wrong_yaml():
     values = ValuesYaml().to_dict()
-    values["sync"]["app"]["hostPortHttps"] = 1000
+    values["sync"]["app"]["port"] = 1000
 
     try:
         ValuesYaml.from_dict(values)
@@ -32,13 +32,3 @@ def test_validation():
     deploy:
         db: true
     """])
-
-    try:
-        validate_strings(["""
-        sync:
-            app:
-                hostPortHttps: 1000
-        """])
-        assert False
-    except Exception as e:
-        assert "common.requireHttps" in str(e)
